<?php
if ( !defined( 'ABSPATH' ) ) {
    wp_die();
}
if ( !class_exists('WPF_Product_Options_Admin') ) {
	class WPF_Product_Options_Admin {
		public function __construct() {
			require_once WP_WPF_DIR . 'include/post-type.php';
			require_once WP_WPF_DIR . 'include/class-wpf-settings.php';
			add_action('admin_enqueue_scripts', array(__CLASS__, 'wpf_backend_enqueue'));
			add_filter('woocommerce_screen_ids', array(__CLASS__, 'wpf_screen_ids'));
			add_filter('woocommerce_product_data_tabs', array(__CLASS__, 'wpf_option_tabs'), 10, 1 );
			add_action('woocommerce_product_data_panels', array(__CLASS__, 'wpf_products_data_panel')) ;
			add_action('woocommerce_process_product_meta', array(__CLASS__, 'wpf_save_boxs_data') );
			add_action('woocommerce_product_after_variable_attributes', array(__CLASS__, 'wpf_options_for_variations'), 10, 3 );
			add_action('woocommerce_save_product_variation', array(__CLASS__, 'wpf_options_save_for_variations'), 20, 2 );
			add_action( 'admin_menu', array(__CLASS__, 'wpf_option_menu') );
			add_action( 'admin_init', array(__CLASS__, 'wpf_option_menu_settings') );
		}
		public static function wpf_screen_ids( $screen_ids ) {
			return array_merge($screen_ids, array('wpf_product_options'));
		}
		public static function wpf_options_for_variations( $loop, $variation_data, $variation ) {
			wp_nonce_field('wpf_product_option_nonce', 'wpf_product_option_nonce'); ?>
    		<div class="panel woocommerce_options_panel wc-metaboxes-wrapper wctp-pricing-wrapper">
			<p class="form-field">
					<?php $value = get_post_meta($variation->ID, 'wpf_enable_product_options', true); ?>
					<label><?php esc_html_e('Enable Product Options', 'wc-wpf'); ?></label>
					<input type="checkbox" name="wpf_enable_product_options[<?php echo esc_attr($loop); ?>]" value="yes" <?php checked('yes', $value); ?> />
				</p>
				<p class="form-field">
					<?php
					$args = array(
						'post_type'      => 'wpf_product_options',
						'posts_per_page' => -1,
						'post_status'    => 'publish',
					);
					$options = get_posts($args);
					$selected_option = get_post_meta($variation->ID, 'wpf_select_option', true); ?>
					<label><?php esc_html_e('Select Option', 'wc-wpf'); ?></label>
					<select class="regular-text" name="wpf_select_option[<?php echo esc_attr($loop); ?>]">
						<option value=""><?php esc_html_e('Select Product Options', 'wc-wpf'); ?></option>
						<?php
						foreach ( $options as $option ) { ?>
							<option value="<?php echo esc_attr($option->ID); ?>" <?php selected($option->ID, $selected_option); ?>><?php esc_html_e($option->post_title); ?></option>
						<?php } ?>
					</select>
				</p>
			<?php
		}
		public static function wpf_options_save_for_variations( $variation_id, $loop ) {
			if ( !isset( $_POST['wpf_product_option_nonce'] ) || !wp_verify_nonce( $_POST['wpf_product_option_nonce'], 'wpf_product_option_nonce') ) {
				return;
			}
			if ( isset( $_POST['wpf_enable_product_options'][$loop] ) ) {
		    	update_post_meta($variation_id, 'wpf_enable_product_options', wc_clean( $_POST['wpf_enable_product_options'][$loop] ) );
		    }else{
		    	update_post_meta($variation_id, 'wpf_enable_product_options', '');
			}
			if ( isset( $_POST['wpf_select_option'][$loop] ) ) {
		    	update_post_meta($variation_id, 'wpf_select_option', wc_clean( $_POST['wpf_select_option'][$loop] ) );
		    }else{
		    	update_post_meta($variation_id, 'wpf_select_option', '');
			}
		}
		public static function wpf_backend_enqueue() {
			if ( function_exists('wp_enqueue_media') ) {
				wp_enqueue_media();
			} else {
				wp_enqueue_style('thickbox');
				wp_enqueue_script('media-upload');
				wp_enqueue_script('thickbox');
			}
			wp_enqueue_style('wp-color-picker');
			wp_enqueue_script('wp-color-picker');
			wp_enqueue_style( 'wpf-backend-style', WP_WPF_URL . 'assets/css/backend_style.css', '', '1.0.9');
			wp_enqueue_script( 'wpf-backend-script', WP_WPF_URL . 'assets/js/backend_scripts.js', array('jquery'), '1.0.9');
		}
		public static function wpf_option_tabs ( $tabs ) {
			$tabs['wpf_options'] = array(
				'label'  => esc_html__('Product Options', 'wc-wpf'),
				'target' => 'wpf_options',
				'class' => 'show_if_simple',
				);
			return $tabs;
		}
		public static function wpf_option_menu() {
			add_menu_page( esc_html__('Product Addons', 'wc-wpf'), esc_html__('Product Addons', 'wc-wpf'), 'manage_options', 'wpf-product-options', array( __CLASS__, 'wpf_labels_settings_page' ), 'dashicons-admin-generic', 60 );
			add_submenu_page( 'wpf-product-options', esc_html__('General Settings', 'wc-wpf'), esc_html__('General Settings', 'wc-wpf'), 'manage_options', 'wpf-product-options', array( __CLASS__, 'wpf_labels_settings_page'), 0);
		}
		public static function wpf_labels_settings_page() {
			WPF_Options_Settings::wpf_labels_settings();
		}
		public static function wpf_option_menu_settings() {
			register_setting('wpf_labels_settings', 'wpf_dropdown_select_label');
			register_setting('wpf_labels_settings', 'wpf_total_price_label');
			register_setting('wpf_labels_settings', 'wpf_table_options_label');
			register_setting('wpf_labels_settings', 'wpf_table_price_label');
			register_setting('wpf_labels_settings', 'wpf_shop_page_product_button_label');
			register_setting('wpf_labels_settings', 'wpf_border_color');
			register_setting('wpf_labels_settings', 'wpf_hide_addons_price');
			register_setting('wpf_labels_settings', 'wpf_hide_summary_table');
			register_setting('wpf_labels_settings', 'wpf_hide_images_title');
		}
		public static function wpf_products_data_panel() {
			global $post;
			$post_id = $post->ID;
			wp_nonce_field('wpf_product_option_nonce', 'wpf_product_option_nonce'); ?>
			<div id = "wpf_options" class="panel woocommerce_options_panel wc-metaboxes-wrapper wpf_options">
				<p class="form-field">
					<?php $value = get_post_meta($post_id, 'wpf_enable_product_options', true); ?>
					<label><?php esc_html_e('Enable Product Options', 'wc-wpf'); ?></label>
					<input type="checkbox" name="wpf_enable_product_options" value="yes" <?php checked('yes', $value); ?> />
				</p>
				<p class="form-field">
					<?php
					$args = array(
						'post_type'      => 'wpf_product_options',
						'posts_per_page' => -1,
						'post_status'    => 'publish',
					);
					$options = get_posts($args);
					$selected_option = get_post_meta($post_id, 'wpf_select_option', true); ?>
					<label><?php esc_html_e('Select Option', 'wc-wpf'); ?></label>
					<select class="regular-text" name="wpf_select_option">
						<option value=""><?php esc_html_e('Select Product Options', 'wc-wpf'); ?></option>
						<?php
						foreach ( $options as $option ) { ?>
							<option value="<?php echo esc_attr($option->ID); ?>" <?php selected($option->ID, $selected_option); ?>><?php esc_html_e($option->post_title); ?></option>
						<?php } ?>
					</select>
				</p>
			</div>
			<?php
		}
		public static function wpf_save_boxs_data( $post_id ) {
			if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
				return;
			}
		    if ( !isset( $_POST['wpf_product_option_nonce'] ) || !wp_verify_nonce( $_POST['wpf_product_option_nonce'], 'wpf_product_option_nonce') ) {
				return;
			}
		    if ( !current_user_can('edit_post', $post_id) ) {
				return;
			}
		    if ( isset( $_POST['wpf_enable_product_options'] ) ) {
		    	update_post_meta($post_id, 'wpf_enable_product_options', wc_clean( $_POST['wpf_enable_product_options'] ) );
		    }else{
		    	update_post_meta($post_id, 'wpf_enable_product_options', '');
			}
			if ( isset( $_POST['wpf_select_option'] ) ) {
		    	update_post_meta($post_id, 'wpf_select_option', wc_clean( $_POST['wpf_select_option'] ) );
		    }else{
		    	update_post_meta($post_id, 'wpf_select_option', '');
			}
		}
	}
	new WPF_Product_Options_Admin();
}