<?php
if ( !defined('ABSPATH') ) {
    wp_die();
}
if ( !class_exists ('WPF_Product_Options_Cart') ) {
	class WPF_Product_Options_Cart {
		public function __construct() {
			add_action('woocommerce_add_to_cart', array(__CLASS__, 'wpf_add_to_cart'), 10, 6);
			add_filter('woocommerce_cart_item_remove_link', array(__CLASS__, 'wpf_cart_item_remove_link'), 10, 3);
			add_filter('woocommerce_cart_contents_count', array(__CLASS__, 'wpf_cart_contents_count'));
			add_action('woocommerce_cart_item_removed', array(__CLASS__, 'wpf_cart_item_removed'), 10, 2);
			add_filter('woocommerce_cart_item_quantity', array(__CLASS__, 'wpf_cart_item_quantity'), 1, 2 );
			add_filter('woocommerce_cart_item_price', array(__CLASS__, 'wpf_cart_item_price'), 10, 3);
			add_filter('woocommerce_cart_item_subtotal', array(__CLASS__, 'wpf_cart_item_subtotal'), 10, 3 );
            add_filter('woocommerce_add_cart_item_data', array(__CLASS__, 'wpf_cart_item_data'), 10, 3);
            add_filter('woocommerce_get_item_data', array(__CLASS__, 'wpf_cart_item_description'), 10, 2);
            add_filter('woocommerce_before_calculate_totals', array(__CLASS__, 'wpf_calculate_price'), 99);
            add_action('woocommerce_checkout_create_order_line_item', array(__CLASS__, 'wpf_order_items_description'), 20, 4);
            add_action('woocommerce_add_to_cart_validation', array(__CLASS__, 'wpf_cart_validation'), 10, 5);
        }
		public static function wpf_add_to_cart( $cart_item_key, $product_id, $quantity, $variation_id, $variation, $cart_item_data ) {
			$rule_id = get_post_meta($product_id, 'wpf_select_option', true);
                $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
                if ( !empty($options) ) {
                    foreach ( $options as $key => $option ) {
						if ( !isset($cart_item_data['wpf_product_ids_'.$key]) ) {
							continue;
						}
						$product_ids = $cart_item_data['wpf_product_ids_'.$key];
						if ( is_array($product_ids) && count($product_ids) > 0 ) {
							$i = 0;
							$product_ids = array_count_values( $product_ids );
							foreach ( $product_ids as $item => $qty ) {
								$wbb_item_id = $item;
								$wbb_item_variation_id = 0;
								$wbb_item_variation = array();
								$wbb_product = wc_get_product( $wbb_item_id );
								if ( $wbb_product ) {
									$wbb_product->set_price(0);
									$wbb_cart_id = WC()->cart->generate_cart_id($wbb_item_id, $wbb_item_variation_id, $wbb_item_variation, array(
										'wpf_parent_id'  => $product_id,
										'wpf_parent_key' => $cart_item_key,
									));
									$wbb_item_key = WC()->cart->find_product_in_cart( $wbb_cart_id);
									if ( !$wbb_item_key ) {
										$wbb_item_key = $wbb_cart_id;
										WC()->cart->cart_contents[$wbb_item_key] = array(
											'product_id'     => $wbb_item_id,
											'variation_id'   => $wbb_item_variation_id,
											'variation'      => $wbb_item_variation,
											'quantity'       => $qty * $quantity,
											'data'           => $wbb_product,
											'wpf_parent_id'  => $product_id,
											'wpf_parent_key' => $cart_item_key,
											'wpf_qty'        => $qty,
										);
									}
									WC()->cart->cart_contents[$cart_item_key]['wpf_keys'][] = $wbb_item_key;
								}
							$i++;
						}
					}
				}
			}
		}
		public static function wpf_cart_item_remove_link( $link, $cart_item_key ) {
			if ( isset(WC()->cart->cart_contents[$cart_item_key]['wpf_parent_id']) ) {
				return '';
			}
			return $link;
		}
		public static function wpf_cart_contents_count( $count ) {
			$cart_contents = WC()->cart->cart_contents;
			$bundled_items = 0;
			foreach ( $cart_contents as $cart_item_key => $cart_item ) {
				if ( !empty($cart_item['wpf_parent_id']) ) {
					$bundled_items += $cart_item['quantity'];
				}
			}
			return intval($count-$bundled_items);
		}
		public static function wpf_cart_item_removed( $cart_item_key, $cart ) {
			if ( isset( $cart->removed_cart_contents[$cart_item_key]['wpf_keys']) ) {
				$wbb_keys = $cart->removed_cart_contents[$cart_item_key]['wpf_keys'];
				foreach ( $wbb_keys as $wbb_key ) {
					unset($cart->cart_contents[$wbb_key]);
				}
			}
		}
		public static function wpf_cart_item_quantity( $quantity, $cart_item_key ) {
			if ( isset(WC()->cart->cart_contents[$cart_item_key]['wpf_parent_id']) ) {
				return WC()->cart->cart_contents[$cart_item_key]['quantity'];
			}
			return $quantity;
		}
		public static function wpf_cart_item_price( $price, $cart_item, $cart_item_key ) {
			if ( isset(WC()->cart->cart_contents[$cart_item_key]['wpf_parent_id']) ) {
				return '';
			}
			return $price;
		}
		public static function wpf_cart_item_subtotal( $subtotal, $cart_item, $cart_item_key ) {
			if ( isset(WC()->cart->cart_contents[$cart_item_key]['wpf_parent_id']) ) {
				return '';
			}
			return $subtotal;
		}
        public static function wpf_cart_validation() {
			$product_id = isset($_POST['variation_id']) ? wc_clean($_POST['variation_id']) : wc_clean($_POST['add-to-cart']);
			if ( (empty($status) || $status == 'no') && empty($rule_id) ) {
				return true;
			}
            if ( isset($_POST['add-to-cart']) ) {
                $flag = true;
                $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
				$status = get_post_meta($product_id, 'wpf_enable_product_options', true);
                $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
                if ( !empty($options) ) {
                    foreach ( $options as $key => $option ) {
                        $logic_status = isset($option['wpf_logic_status']) ? $option['wpf_logic_status'] : '';
                        $logic_option = isset($option['wpf_logic_option']) ? $option['wpf_logic_option'] : '';
                        $logic_value = !empty($option['wpf_logic_value']) ? $option['wpf_logic_value'] : '';
                        $logic = !empty($option['wpf_logic_select']) ? $option['wpf_logic_select'] : '';
                        if ( !empty($logic_status) && !empty($logic_value) ) {
                            $required = '';
                        } else {
                            $required = $option['wpf_option_required'];
                        }
                        $logic_option_setting = !empty($options[$logic_option]) ? $options[$logic_option] : array();
                        $logic_option_type = !empty($logic_option_setting['wpf_rule_type']) ? $logic_option_setting['wpf_rule_type'] : '';
                        $multi_label = array_filter($option['wpf_multi_options_label']);
                        $meta_key = sprintf('wpf_%s_%s', $logic_option_type, $logic_option);
                        switch ( $option['wpf_rule_type'] ) {
                            case 'radio':
                                if ( !empty($multi_label) ) {
                                    if ( !isset($_POST['wpf_radio_' . $key]) && 'yes' == $required ) {
                                        $flag = false;
                                    }
                                }
                            break;
                            case 'dropdown':
                                if ( !empty($multi_label) ) {
                                    if ( !isset($_POST['wpf_dropdown_' . $key]) && 'yes' == $required ) {
                                        $flag = false;
                                    }   
                                }
                            break;
                            case 'checkboxes':
                                if ( !empty($multi_label) ) {
                                    if ( !isset($_POST['wpf_checkboxes_' . $key]) && 'yes' == $required ) {
                                        $flag = false;
                                    }
                                }
                            break;
                            case 'images':
                                if ( !empty($multi_label) ) {
                                    if ( !isset($_POST['wpf_images_' . $key]) && 'yes' == $required ) {
                                        $flag = false;
                                    }
                                }
                            break;
                            case 'text_field':
                                if ( !isset($_POST['wpf_text_field_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'text_area':
                                if ( !isset($_POST['wpf_text_area_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'price':
                                if ( !isset($_POST['wpf_price_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'quantity':
                                if ( !isset($_POST['wpf_quantity_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'file':
                                if ( !isset($_FILES['wpf_file_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'time':
                                if ( !isset($_POST['wpf_time_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'date':
                                if ( !isset($_POST['wpf_date_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'colorpicker':
                                if ( !isset($_POST['wpf_colorpicker_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'multiselect':
                                if ( !isset($_POST['wpf_multiselect_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'range_picker':
                                if ( !isset($_POST['wpf_range_picker_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                            case 'date_range_picker':
                                if ( !isset($_POST['wpf_date_range_picker_' . $key]) && 'yes' == $required ) {
                                    $flag = false;
                                }
                            break;
                        }
                    }
                } else {
					return;
				}
                if ( !$flag ) {
                    wc_add_notice( esc_html__( 'Some required fields are missing!', 'wc-wpf' ), 'error' );
                    return false;
                } else {
                    return true;
                }
            }
        }
        public static function wpf_cart_item_data( $cart_item_data, $product_id, $variation_id ) {
            if ( !empty($variation_id) ) {
                $rule_id = get_post_meta($variation_id, 'wpf_select_option', true);
            } else {
                $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
            }
            $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
            if ( !empty($options) ) {
                foreach ( $options as $key => $option ) {
                    switch ( $option['wpf_rule_type'] ) {
                        case 'radio':
                            $cart_item_data['wpf_radio_buttons_' . $key] = (isset($_POST['wpf_radio_' . $key]) && '' !== $_POST['wpf_radio_' . $key]) ? wc_clean($_POST['wpf_radio_' . $key]) : '';
                        break;
                        case 'dropdown':
                            $cart_item_data['wpf_dropdown_' . $key] = (isset($_POST['wpf_dropdown_' . $key]) && '' !== $_POST['wpf_dropdown_' . $key]) ? wc_clean($_POST['wpf_dropdown_' . $key]) : '';
                        break;
                        case 'checkboxes':
                            $cart_item_data['wpf_checkbox_buttons_' . $key] = (isset($_POST['wpf_checkboxes_' . $key]) && '' !== $_POST['wpf_checkboxes_' . $key]) ? wc_clean($_POST['wpf_checkboxes_' . $key]) : '';
                        break;
                        case 'images':
                            $cart_item_data['wpf_image_field_' . $key] = (isset($_POST['wpf_images_' . $key]) && '' !== $_POST['wpf_images_' . $key]) ? wc_clean($_POST['wpf_images_' . $key]) : '';
                        break;
                        case 'text_field':
                            $cart_item_data['wpf_text_field_' . $key] = isset($_POST['wpf_text_field_' . $key]) ? wc_clean($_POST['wpf_text_field_' . $key]) : '';
                        break;
                        case 'text_area':
                            $cart_item_data['wpf_textarea_' . $key] = isset($_POST['wpf_text_area_' . $key]) ? wc_clean($_POST['wpf_text_area_' . $key]) : '';
                        break;
                        case 'price':
                            $cart_item_data['wpf_price_field_' . $key] = isset($_POST['wpf_price_' . $key]) ? wc_clean($_POST['wpf_price_' . $key]) : '';
                        break;
                        case 'file':
                            if ( isset($_FILES['wpf_file_' . $key]) ) {
                                if ( !$_FILES['wpf_file_' . $key]['error'] ) {
                                    $addon_id = array();
                                    $attach_id = media_handle_upload( 'wpf_file_' . $key, $product_id );
                                    $addon_id['media_id'] = $attach_id;
                                    $addon_id['media_url'] = wp_get_attachment_url( esc_attr( $attach_id ) );
                                    $cart_item_data['wpf_upload_file_field_' . $key] = $addon_id;
                                }
                            }
                        break;
                        case 'quantity':
                            $cart_item_data['wpf_quatity_field_' . $key] = isset($_POST['wpf_quantity_' . $key]) ? wc_clean($_POST['wpf_quantity_' . $key]) : '';
                        break;
                        case 'date':
                            $cart_item_data['wpf_date_field_' . $key] = isset($_POST['wpf_date_' . $key]) ? wc_clean($_POST['wpf_date_' . $key]) : '';
                        break;
                        case 'time':
                            $cart_item_data['wpf_time_field_' . $key] = isset($_POST['wpf_time_' . $key]) ? wc_clean($_POST['wpf_time_' . $key]) : '';
                        break;
                        case 'colorpicker':
                            $cart_item_data['wpf_colorpicker_field_' . $key] = isset($_POST['wpf_colorpicker_' . $key]) ? wc_clean($_POST['wpf_colorpicker_' . $key]) : '';
                        break;
                        case 'multiselect':
                            $cart_item_data['wpf_multiselect_' . $key] = (isset($_POST['wpf_multiselect_' . $key]) && '' !== $_POST['wpf_multiselect_' . $key]) ? wc_clean($_POST['wpf_multiselect_' . $key]) : '';
                        break;
                        case 'range_picker':
                            $cart_item_data['wpf_range_field_' . $key] = isset($_POST['wpf_range_picker_' . $key]) ? wc_clean($_POST['wpf_range_picker_' . $key]) : '';
                        break;
                        case 'date_range_picker':
                            $cart_item_data['wpf_date_range_field_' . $key] = isset($_POST['wpf_date_range_picker_' . $key]) ? wc_clean($_POST['wpf_date_range_picker_' . $key]) : '';
                        break;
							
							case 'composite_products':
							$product_ids = array();
							if ( !empty($_POST['wpf_product_' . $key]) ) {
								$product_ids = $_POST['wpf_product_' . $key];
							}
							$cart_item_data['wpf_product_ids_' . $key] = $product_ids;
							break;
                    }
                }
            }
            return $cart_item_data;
        }
        public static function wpf_calculate_price() {
			if ( is_admin() && ! defined( 'DOING_AJAX' ) ) {
				return;
            }
            foreach ( WC()->cart->get_cart() as $key => $cart_item ) {
				if ( isset($cart_item['wpf_parent_id']) && !empty($cart_item['wpf_parent_id']) ) {
					$cart_item['data']->set_price(0);
				}
                $product_id = !empty($cart_item['variation_id'])  ? $cart_item['variation_id'] : $cart_item['product_id'];
                $product = wc_get_product($product_id);
				$base_price = $product->get_price();
				$quantity = $cart_item['quantity'];
				$base_price =  self::wctp_custom_product_price( $base_price, $product_id, $quantity );
                $cart_price = 0;
                $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
				if ( empty($rule_id) ) {
					continue;
				}
                $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
                if ( !empty($options) ) {
                    foreach ( $options as $key => $option ) {
                        $price = !empty($option['wpf_options_price']) ? $option['wpf_options_price'] : 0;
                        $type = $option['wpf_option_pricing_type'];
                        $option_price_types = $option['wpf_multi_options_price_type'];
                        switch ( $option['wpf_rule_type'] ) {
                            case 'radio':
                                if ( isset($cart_item['wpf_radio_buttons_' . $key]) && '' !== $cart_item['wpf_radio_buttons_' . $key] ) {
                                    $index = $cart_item['wpf_radio_buttons_' . $key];
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'dropdown':
                                if ( isset($cart_item['wpf_dropdown_' . $key]) && '' !== $cart_item['wpf_dropdown_' . $key] ) {
                                    $index = $cart_item['wpf_dropdown_' . $key];
                                    if ( $price == '' ) {
                                        $price = 0;
                                    }
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'checkboxes':
                                if ( !empty($cart_item['wpf_checkbox_buttons_' . $key]) ) {
                                    foreach ( $cart_item['wpf_checkbox_buttons_' . $key] as $index ) {
                                        $option_prices = $option['wpf_multi_options_price'];
                                        $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                        $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                        $price = self::wpf_convert_pricing($type, $base_price, $price);
                                        $cart_price += $price;
                                    }
                                }
                            break;
							case 'composite_products':
								if ( !empty($cart_item['wpf_product_ids_'.$key]) ) {
									foreach ( $cart_item['wpf_product_ids_'.$key] as $prod_id ) {
										$product = wc_get_product($prod_id);
										 $cart_price += $product->get_price();
									}
								}
                            break;
                            case 'images':
                                if ( isset($cart_item['wpf_image_field_' . $key]) && '' !== $cart_item['wpf_image_field_' . $key] ) {
                                    if ( 'yes' == $option['wpf_option_allow_multiple'] ) {
                                        foreach ( $cart_item['wpf_image_field_' . $key] as $index ) {
                                            $option_prices = $option['wpf_multi_options_price'];
                                            $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                            $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                            $price = self::wpf_convert_pricing($type, $base_price, $price);
                                            $cart_price += $price;
                                        }
                                    } else {
                                        $index = $cart_item['wpf_image_field_' . $key];
                                        $option_prices = $option['wpf_multi_options_price'];
                                        $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                        $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                        $price = self::wpf_convert_pricing($type, $base_price, $price);
                                        $cart_price += $price;
                                    }
                                }
                            break;
                            case 'text_field':
                                if ( !empty($cart_item['wpf_text_field_' . $key]) ) {
                                    $entered_text = $cart_item['wpf_text_field_' . $key];
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'file':
                                if ( !empty($cart_item['wpf_upload_file_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'text_area':
                                if ( !empty($cart_item['wpf_textarea_' . $key]) ) {
                                    $text_pricing = $option['wpf_option_text_pricing'];
                                    $entered_text = $cart_item['wpf_textarea_' . $key];
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( 'per_char' == $text_pricing ) {
                                        $price = (strlen($entered_text) * $price);
                                    } else if ( 'per_word' == $text_pricing ) {
                                        $price = (str_word_count($entered_text) * $price);
                                    }
                                    $cart_price += $price;
                                }
                            break;
                            case 'price':
                                if ( !empty($cart_item['wpf_price_field_' . $key]) ) {
                                    $price = !empty($cart_item['wpf_price_field_' . $key]) ? $cart_item['wpf_price_field_' . $key] : 0;
                                    $cart_price += $price;
                                }
                            break;
                            case 'quantity':
                                if ( !empty($cart_item['wpf_quatity_field_' . $key]) ) {
                                    $entered_qty = !empty($cart_item['wpf_quatity_field_' . $key]) ? $cart_item['wpf_quatity_field_' . $key] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $price *= $entered_qty;
                                    $cart_price += $price;
                                }
                            break;
                            case 'date':
                                if ( !empty($cart_item['wpf_date_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'time':
                                if ( !empty($cart_item['wpf_time_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'colorpicker':
                                if ( !empty($cart_item['wpf_colorpicker_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
                            break;
                            case 'multiselect':
                                if ( isset($cart_item['wpf_multiselect_' . $key]) && '' !== $cart_item['wpf_multiselect_' . $key] ) {
                                    foreach ( $cart_item['wpf_multiselect_' . $key] as $index ) {
                                        $option_prices = $option['wpf_multi_options_price'];
                                        $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                        $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : '';
                                        $price = self::wpf_convert_pricing($type, $base_price, $price);
                                        $cart_price += $price;
                                    }
                                }
                            break;
                            case 'range_picker':
                                if ( !empty($cart_item['wpf_range_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $price *= $cart_item['wpf_range_field_' . $key];
                                    $cart_price += $price;
                                }
                            break;
                            case 'date_range_picker':
                                if ( !empty($cart_item['wpf_date_range_field_' . $key]) ) {
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    $cart_price += $price;
                                }
								break;
                        }
                    }
                }
                $cart_item['data']->set_price($base_price);
				$price = $cart_item['data']->get_price();
				$price += $cart_price;
				$cart_item['data']->set_price($price);
			}
        }
        public static function wpf_cart_item_description( $item_data, $cart_item ) {
            $product_id = !empty($cart_item['variation_id']) ? $cart_item['variation_id'] : $cart_item['product_id'];
            $base_price = wc_get_product($product_id)->get_price();
            $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
            $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
//             $item_name = $item_name . '<br />';
            if ( !empty($options) ) {
                foreach ( $options as $key => $option ) {
                    $label = esc_html__($option['wpf_option_label'], 'wc-wpf');
                    $option_labels = $option['wpf_multi_options_label'];
                    $price = $option['wpf_options_price'];
                    $type = $option['wpf_option_pricing_type'];
                    $option_price_types = $option['wpf_multi_options_price_type'];
                    switch ( $option['wpf_rule_type'] ) {
                        case 'radio':
                            if ( isset($cart_item['wpf_radio_buttons_' . $key]) && '' !== $cart_item['wpf_radio_buttons_' . $key] ) {
                                $index = $cart_item['wpf_radio_buttons_' . $key];
                                $option_prices = $option['wpf_multi_options_price'];
                                $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                if ( !empty($option_labels[$index]) ) {
                                    $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                     $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
									$item_data[] = array(
										'key'     => $label,
										'value'   => $cart_data,
										'display' => '',
									);
                                }
                            }
                        break;
                        case 'dropdown':
                            if ( isset($cart_item['wpf_dropdown_' . $key]) && '' !== $cart_item['wpf_dropdown_' . $key] ) {
                                $index = isset($cart_item['wpf_dropdown_' . $key]) ? $cart_item['wpf_dropdown_' . $key] : 0;
                                $option_prices = $option['wpf_multi_options_price'];
                                $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                if ( !empty($option_labels[$index]) ) {
                                    $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                     $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
									$item_data[] = array(
										'key'     => $label,
										'value'   => $cart_data,
										'display' => '',
									);
                                }
                            }
                        break;
                        case 'checkboxes':
                            if ( isset($cart_item['wpf_checkbox_buttons_' . $key]) && '' !== $cart_item['wpf_checkbox_buttons_' . $key] ) {
                                foreach ( $cart_item['wpf_checkbox_buttons_' . $key] as $index ) {
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                         $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
										$item_data[] = array(
											'key'     => $label,
											'value'   => $cart_data,
											'display' => '',
										);
                                    }
                                }
                            }
                        break;
                        case 'images':
                            if ( isset($cart_item['wpf_image_field_' . $key]) && '' !== $cart_item['wpf_image_field_' . $key] ) {
                                if ( $option['wpf_option_allow_multiple'] == 'yes' ) {
                                    foreach ( $cart_item['wpf_image_field_' . $key] as $index ) {
                                        $option_prices = $option['wpf_multi_options_price'];
                                        $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                        $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                        $price = self::wpf_convert_pricing($type, $base_price, $price);
                                        if ( !empty($option_labels[$index]) ) {
                                            $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                             $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
											$item_data[] = array(
												'key'     => $label,
												'value'   => $cart_data,
												'display' => '',
											);
                                        }
                                    }
                                } else {
                                    $index = $cart_item['wpf_image_field_' . $key];
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                         $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
										$item_data[] = array(
											'key'     => $label,
											'value'   => $cart_data,
											'display' => '',
										);
                                    }
                                }
                            }
                        break;
                        case 'text_field':
                            if ( !empty($cart_item['wpf_text_field_' . $key]) ) {
                                $entered_text = $cart_item['wpf_text_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $entered_text);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'file':
                            if ( !empty($cart_item['wpf_upload_file_field_' . $key]) ) {
                                $path = '<a href="' . esc_url($cart_item['wpf_upload_file_field_' . $key]['media_url']) . '" target="_blank">' . esc_html__('View', 'wc-wpf') . '</a>';
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $path);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'text_area':
                            if ( !empty($cart_item['wpf_textarea_' . $key]) ) {
                                $entered_text = $cart_item['wpf_textarea_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $text_pricing = $option['wpf_option_text_pricing'];
                                if ( 'per_char' == $text_pricing ) {
                                    $price = (strlen($entered_text) * $price);
                                } else if ( 'per_word' == $text_pricing ) {
                                    $price = (str_word_count($entered_text) * $price);
                                }
                                $cart_data = self::wpf_set_order_data($price, $entered_text);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
                                $item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'price':
                            if ( !empty($cart_item['wpf_price_field_' . $key]) ) {
                                $price = $cart_item['wpf_price_field_' . $key];
                                $cart_data = self::wpf_set_order_data($price, '');
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'quantity':
                            if ( !empty($cart_item['wpf_quatity_field_' . $key]) ) {
                                $entered_qty = !empty($cart_item['wpf_quatity_field_' . $key]) ? $cart_item['wpf_quatity_field_' . $key] : 0;
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $price *= $entered_qty;
                                $cart_data = self::wpf_set_order_data($price, '');
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'date':
                            if ( !empty($cart_item['wpf_date_field_' . $key]) ) {
                                $entered_date = $cart_item['wpf_date_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $entered_date);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'time':
                            if ( !empty($cart_item['wpf_time_field_' . $key]) ) {
                                $entered_time = $cart_item['wpf_time_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $entered_time);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'colorpicker':
                            if ( !empty($cart_item['wpf_colorpicker_field_' . $key]) ) {
                                $added_color = $cart_item['wpf_colorpicker_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $added_color);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'multiselect':
                            if ( isset($cart_item['wpf_multiselect_' . $key]) && '' !== $cart_item['wpf_multiselect_' . $key] ) {
                                foreach ( $cart_item['wpf_multiselect_' . $key] as $index ) {
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $cart_data = self::wpf_set_order_data($price, $option_labels[$index]);
//                                         $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
										$item_data[] = array(
											'key'     => $label,
											'value'   => $cart_data,
											'display' => '',
										);
                                    }
                                }
                            }
                        break;
                        case 'range_picker':
                            if ( !empty($cart_item['wpf_range_field_' . $key]) ) {
                                $entered_qty = $cart_item['wpf_range_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $price = ($price * $entered_qty);
                                $cart_data = self::wpf_set_order_data($price, $entered_qty);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                        case 'date_range_picker':
                            if ( !empty($cart_item['wpf_date_range_field_' . $key]) ) {
                                $entered_date = $cart_item['wpf_date_range_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $cart_data = self::wpf_set_order_data($price, $entered_date);
//                                 $item_name .= sprintf('%s: %s<br />', $label, $cart_data);
								$item_data[] = array(
									'key'     => $label,
									'value'   => $cart_data,
									'display' => '',
								);
                            }
                        break;
                    }
                }
            }
			return $item_data;
        }
        public static function wpf_set_order_data($price, $label ) {
            $hide_price = get_option('wpf_hide_addons_price');
            if ( 0 == $price || 'yes' == $hide_price ) {
                $price = '';
            } else {
                $price = wc_price($price);
            }
            if ( !empty($price) ) {
                $order_data = sprintf('%s (%s)', $label, $price);
            } else {
                $order_data = $label;
            }
            return $order_data;
        }
        public static function wpf_order_items_description( $item, $cart_item_key, $values, $order ) {
            $product_id = !empty($item['variation_id']) ? $item['variation_id'] : $item['product_id'];
            $base_price = wc_get_product($product_id)->get_price();
            $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
            $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
            if ( !empty($options) ) {
                $i = 1;
                foreach ( $options as $key => $option ) {
                    $label = sprintf('%s %s', $i, esc_html__($option['wpf_option_label'], 'wc-wpf'));
                    $option_labels = $option['wpf_multi_options_label'];
                    $price = $option['wpf_options_price'];
                    $type = $option['wpf_option_pricing_type'];
                    $option_price_types = $option['wpf_multi_options_price_type'];
                    switch ( $option['wpf_rule_type'] ) {
                        case 'radio':
                            if ( isset($values['wpf_radio_buttons_' . $key]) && '' !== $values['wpf_radio_buttons_' . $key] ) {
                                $order_data = '';
                                $index = $values['wpf_radio_buttons_' . $key];
                                $option_prices = $option['wpf_multi_options_price'];
                                $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                if ( !empty($option_labels[$index]) ) {
                                    $order_data = self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                    $item->update_meta_data($label, $order_data);
                                }
                            }
                        break;
                        case 'dropdown':
                            if ( isset($values['wpf_dropdown_' . $key]) && '' !== $values['wpf_dropdown_' . $key] ) {
                                $order_data = '';
                                $index = !empty($values['wpf_dropdown_' . $key]) ? $values['wpf_dropdown_' . $key] : 0;
                                $option_prices = $option['wpf_multi_options_price'];
                                $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                if ( !empty($option_labels[$index]) ) {
                                    $order_data = self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                    $item->update_meta_data($label, $order_data);
                                }
                            }
                        break;
                        case 'checkboxes':
                            if ( isset($values['wpf_checkbox_buttons_' . $key]) && '' !== $values['wpf_checkbox_buttons_' . $key] ) {
                                $order_data = '';
                                foreach ( $values['wpf_checkbox_buttons_' . $key] as $index ) {
                                    echo $index;
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $order_data .= self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                    }
                                }
                                if ( !empty($order_data) ) {
                                    $item->update_meta_data($label, $order_data);
                                }
                            }
                        break;
                        case 'images':
                            if ( isset($values['wpf_image_field_' . $key]) && '' !== $values['wpf_image_field_' . $key] ) {
                                $order_data = '';
                                if ( 'yes' == $option['wpf_option_allow_multiple'] ) {
                                    foreach ( $values['wpf_image_field_' . $key] as $index ) {
                                        $option_prices = $option['wpf_multi_options_price'];
                                        $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                        $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                        $price = self::wpf_convert_pricing($type, $base_price, $price);
                                        if ( !empty($option_labels[$index]) ) {
                                            $order_data = self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                        }
                                    }
                                    if ( !empty($order_data) ) {
                                        $item->update_meta_data($label, $order_data);
                                    }
                                } else {
                                    $index = $values['wpf_image_field_' . $key];
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $order_data = self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                        $item->update_meta_data($label, $order_data);
                                    }
                                }
                            }
                        break;
                        case 'text_field':
                            if ( !empty($values['wpf_text_field_' . $key]) ) {
                                $order_data = '';
                                $entered_text = $values['wpf_text_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, esc_html__($entered_text, 'wc-wpf'));
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'file':
                            if ( !empty($values['wpf_upload_file_field_' . $key]) ) {
                                $order_data = '';
                                $path = '<a href="'.esc_url($values['wpf_upload_file_field_' . $key]['media_url']) . '">' . esc_html__('View', 'wc-wpf') . '</a>';
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, $path);
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'text_area':
                            if ( !empty($values['wpf_textarea_' . $key]) ) {
                                $order_data = '';
                                $entered_text = $values['wpf_textarea_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $text_pricing = $option['wpf_option_text_pricing'];
                                if ( 'per_char' == $text_pricing ) {
                                    $price = (strlen($entered_text) * $price);
                                } else if ( 'per_word' == $text_pricing ) {
                                    $price = (str_word_count($entered_text) * $price);
                                }
                                $order_data = self::wpf_set_order_data($price, esc_html__($entered_text, 'wc-wpf'));
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'price':
                            if ( !empty($values['wpf_price_field_' . $key]) ) {
                                $order_data = '';
                                $price = $values['wpf_price_field_' . $key];
                                $order_data = self::wpf_set_order_data($price, '');
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'quantity':
                            if ( !empty($values['wpf_quatity_field_' . $key]) ) {
                                $order_data = '';
                                $entered_qty = $values['wpf_quatity_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $price *= $entered_qty;
                                $order_data = self::wpf_set_order_data($price, '');
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'date':
                            if ( !empty($values['wpf_date_field_' . $key]) ) {
                                $order_data = '';
                                $entered_date = $values['wpf_date_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, $entered_date);
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'time':
                            if ( !empty($values['wpf_time_field_' . $key]) ) {
                                $order_data = '';
                                $entered_time = $values['wpf_time_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, $entered_time);
                                $item->update_meta_data($label, $entered_time);
                            }
                        break;
                        case 'colorpicker':
                            if ( !empty($values['wpf_colorpicker_field_'.$key]) ) {
                                $order_data = '';
                                $added_color = $values['wpf_colorpicker_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, $added_color);
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'multiselect':
                            if ( isset($values['wpf_multiselect_' . $key]) && '' !== $values['wpf_multiselect_' . $key] ) {
                                $order_data = '';
                                foreach ( $values['wpf_multiselect_' . $key] as $index ) {
                                    $option_prices = $option['wpf_multi_options_price'];
                                    $price = !empty($option_prices[$index]) ? $option_prices[$index] : 0;
                                    $type = !empty($option_price_types[$index]) ? $option_price_types[$index] : 0;
                                    $price = self::wpf_convert_pricing($type, $base_price, $price);
                                    if ( !empty($option_labels[$index]) ) {
                                        $order_data = self::wpf_set_order_data($price, esc_html__($option_labels[$index], 'wc-wpf'));
                                    }
                                }
                                if ( !empty($order_data) ) {
                                    $item->update_meta_data($label, $order_data);
                                }
                            }
                        break;
                        case 'range_picker':
                            if ( !empty($values['wpf_range_field_'.$key]) ) {
                                $order_data = '';
                                $entered_qty = $values['wpf_range_field_' . $key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $price = ($price * $entered_qty);
                                $order_data = self::wpf_set_order_data($price, $entered_qty);
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                        case 'date_range_picker':
                            if ( !empty($values['wpf_date_range_field_' . $key]) ) {
                                $order_data = '';
                                $entered_date = $values['wpf_date_range_field_'.$key];
                                $price = self::wpf_convert_pricing($type, $base_price, $price);
                                $order_data = self::wpf_set_order_data($price, $entered_date);
                                $item->update_meta_data($label, $order_data);
                            }
                        break;
                    }
                    $i++;
                }
            }
        }
        public static function wpf_convert_pricing( $type, $base_price, $option_price ) {
            if ( '' == $option_price ) {
                $option_price = 0;
            }
            if ( 'flate_fee' == $type ) {
                return $option_price;
            } else {
				if ( $option_price > 0 ) {
                	return ($option_price / 100) * $base_price;
				} else {
					return $option_price;
				}
            }
        }
// 		tiered pricing compatibility script
		public static function wctp_custom_product_price( $price, $product_id, $qty ) {
			wc_delete_product_transients($product_id);
			$data = self::wctp_pricing_table_status( $product_id );
			if ( !$data ) {
				return $price;
			}
			$ruleset = $data['discount_table'];
			$type = $data['pricing_type'];
			$price = self::wctp_get_price($price, $ruleset, $type, $qty);
			return $price;
		}
		public static function wctp_get_price( $price, $ruleset, $type, $qty ) {
			if ( empty($ruleset) ) {
				return $price;
			}
			foreach ( $ruleset as $key => $rule ) {
				if ( (absint($qty) >= absint($rule['wctp_quantity'])) && ( !empty($ruleset[$key+1]['wctp_quantity']) && absint($qty) < absint($ruleset[$key+1]['wctp_quantity']) ) ) {
					$price = self::wctp_calculate_price($rule['wctp_discount'], $type, $price);
					return $price;
				} else if ( (absint($qty) >= absint($rule['wctp_quantity'])) && empty($ruleset[$key+1]['wctp_quantity']) ) {
					$price = self::wctp_calculate_price($rule['wctp_discount'], $type, $price);
					return $price;
				}
			}
			return $price;
		}
		public static function wctp_calculate_price( $amount, $type, $price ) {
			if ( $type == 'fixed' ) {
				$price = $price - $amount;
				return $price;
			} else {
				$price = $price - (($price / 100) * $amount);
				return $price;
			}
		}
		public static function wctp_pricing_table_status( $product_id ) {
			$table_data = array();
			$product = wc_get_product($product_id);
			$pricing_status = get_post_meta($product_id, 'wctp_pricing_type_visibility', true);
			if ( 'disable' == $pricing_status ) {
				return false;
			} else if ( 'enable' == $pricing_status ) {
				$pricing_type = get_post_meta( $product_id, 'wctp_pricing_type', true);
				$discount_table = get_post_meta( $product_id, 'wctp_discount_table_data', true);
				$table_style = get_post_meta( $product_id, 'wctp_table_layout', true);
				return array( 'pricing_type' => $pricing_type, 'discount_table' => $discount_table, 'table_style' => $table_style );
			} else {
				if ( $product->is_type('variation') ) {
					$product_id = wp_get_post_parent_id($product_id);
				}
				$terms = get_the_terms ( $product_id, 'product_cat' );
				if ( !is_wp_error($terms) && !empty($terms) ) {
					foreach ( $terms as $term ) {
						$cat_pricing = get_term_meta($term->term_id, 'wctp_pricing_type_visibility', true);
						if ( 'enable' == $cat_pricing ) {
							$discount_table = get_term_meta($term->term_id, 'wctp_discount_table_data', true);
							$pricing_type = get_term_meta($term->term_id, 'wctp_pricing_type', true);
							$table_style = get_term_meta( $term->term_id, 'wctp_table_layout', true);
							return array( 'pricing_type' => $pricing_type, 'discount_table' => $discount_table, 'table_style' => $table_style );
						} else {
							continue;
						}
					}
				}
			}
			if ( 'yes' == get_option('wctp_pricing_type_visibility') ) {
				$pricing_type = get_option('wctp_pricing_type');
				$discount_table = get_option('wctp_discount_table_data');
				$table_style = get_option('wctp_table_layout');
				return array('pricing_type' => $pricing_type, 'discount_table' => $discount_table, 'table_style' => $table_style);
			}
			return false;
		}
    }
    new WPF_Product_Options_Cart();
}