<?php
if ( !defined('ABSPATH') ) {
    wp_die();
}
if( !class_exists( 'WPF_Product_Options_Frontend' ) ) {
	class WPF_Product_Options_Frontend {
		public function __construct() {
            require_once ABSPATH . 'wp-admin/includes/image.php';
			require_once ABSPATH . 'wp-admin/includes/file.php';
			require_once ABSPATH . 'wp-admin/includes/media.php';
            require_once WP_WPF_DIR . 'include/cart.php';
            add_action('wp_enqueue_scripts', array(__CLASS__, 'wpf_frontend_enqueue'));
            add_action( 'woocommerce_before_add_to_cart_button', array(__CLASS__, 'wpf_product_extra_options' ), 20);
			add_shortcode( 'product_extra_options', array(__CLASS__, 'wpf_product_extra_options_shortcode' ), 20);
            add_filter('woocommerce_loop_add_to_cart_link', array(__CLASS__, 'wpf_shop_cart_button'));
            add_action('wp_head', array(__CLASS__, 'wpf_option_styling'));
        }
        public static function wpf_frontend_enqueue() {
			if ( is_product() ) {
				wp_enqueue_style( 'wpf-frontend-style', WP_WPF_URL . 'assets/css/frontend_styles.css', '', '1.0.9');
				wp_enqueue_style( 'pick1', WP_WPF_URL . 'assets/css/daterangepicker.css', '', '1.0.0');
				wp_enqueue_style( 'select2', WP_WPF_URL . 'assets/css/select2.min.css', '', '1.0.0');
				wp_enqueue_script( 'wpf-frontend-script', WP_WPF_URL . 'assets/js/frontend_scripts.js', array('jquery'), '1.0.9');
				wp_enqueue_script( 'select2', WP_WPF_URL . 'assets/js/select2.min.js');
				wp_enqueue_script( 'pick1', WP_WPF_URL . 'assets/js/moment.min.js');
				wp_enqueue_script( 'pick2', WP_WPF_URL . 'assets/js/daterangepicker.min.js');
				$product = wc_get_product(get_the_ID());
				$option_label = get_option('wpf_table_options_label');
				$option_label = !empty($option_label) ? esc_html__($option_label, 'wc-wpf') : esc_html__('Options', 'wc-wpf');
				$price_label = get_option('wpf_table_price_label');
				$price_label = !empty($price_label) ? esc_html__($price_label, 'wc-wpf') : esc_html__('Price', 'wc-wpf');
				$total_price_label = get_option('wpf_total_price_label');
				$total_price_label = !empty($total_price_label) ? esc_html__($total_price_label, 'wc-wpf') : esc_html__('Total Price', 'wc-wpf');
				$decimal_sep = get_option('woocommerce_price_decimal_sep');
				$thousand_sep = get_option('woocommerce_price_thousand_sep');
				$currency_pos = get_option('woocommerce_currency_pos');
				$decimal_no = get_option('woocommerce_price_num_decimals');
				$product_price = $product->get_price();
				if ( !empty($product->get_tax_status()) && 'none' != $product->get_tax_status() ) {
					if ( 'yes' == get_option('woocommerce_prices_include_tax') ) {
						$product_price = wc_get_price_including_tax($product);
					}
				}
				wp_localize_script('wpf-frontend-script', 'wpf_product_option', array(
					'ajaxurl'           => admin_url('admin-ajax.php'),
					'product_title'     => esc_attr($product->get_name()),
					'product_price'     => esc_attr($product_price),
					'currency_symbol'   => wp_kses_post(get_woocommerce_currency_symbol()),
					'total_price_label' => $total_price_label,
					'th_label'          => $option_label,
					'th_price_label'    => $price_label,
					'decimal_sep'       => $decimal_sep,
					'thousand_sep'      => $thousand_sep,
					'currency_pos'      => $currency_pos,
					'nonce' => wp_create_nonce('wpf_ajax_nonce'),
					'decimal_no'        => $decimal_no,
					'product_type'      => $product->is_type('variable'),
					'choose_option_notice' => esc_html__('Some required options are missing', 'wc-wpf'),
				));
			}
		}
		public static function wpf_product_extra_options_shortcode() {
			global $product;
            $flag = true;
			if ( $product->is_type('variable') ) {
				ob_start();
                echo '<div class="wpf_variation_addon wpf_prduct_addons"></div>
                <div class="wpf_loader"><div></div><div></div><div></div><div></div></div>';
                return ob_get_clean();
            }
            $status = get_post_meta(get_the_ID(), 'wpf_enable_product_options', true);
            if ( empty($status) || 'no' == $status ) {
                return;
            }
            $rule_id = get_post_meta(get_the_ID(), 'wpf_select_option', true);
            if ( empty($rule_id) ) {
                return;
            }
			ob_start();
            echo wpf_options_html( $rule_id, $product );
			return ob_get_clean();
		}
        public static function wpf_product_extra_options() {
            global $product;
            $flag = true;
			if ( $product->is_type('variable') ) {
                echo '<div class="wpf_variation_addon wpf_prduct_addons"></div>
                <div class="wpf_loader"><div></div><div></div><div></div><div></div></div>';
                return;
            }
            $status = get_post_meta(get_the_ID(), 'wpf_enable_product_options', true);
            if ( empty($status) || 'no' == $status ) {
                return;
            }
            $rule_id = get_post_meta(get_the_ID(), 'wpf_select_option', true);
            if ( empty($rule_id) ) {
                return;
            }
            echo wpf_options_html( $rule_id, $product );
        }
        public static  function wpf_shop_cart_button ( $button ) {
            global $product;
            $status = get_post_meta($product->get_id(), 'wpf_enable_product_options', true);
            $rule_id = get_post_meta($product->get_id(), 'wpf_select_option', true);
            if ( (empty($status) || $status == 'no') && empty($rule_id) ) {
                return $button;
            } else {
                $label = get_option('wpf_shop_page_product_button_label');
                $label = !empty($label) ? esc_html__($label, 'wc-wpf') : esc_html__('Select Options', 'wc-wpf');
                return '<a class="button" href="' . get_the_permalink($product->get_id()) . '">' . esc_html($label) . '</a>';
            }
        }
        public static function wpf_option_styling() { 
			?>
            <style>
            <?php 
			$border_color = get_option('wpf_border_color');
            $border_color = !empty($border_color) ? $border_color : 'green'; ?>
            .wpf_image_border{
                border: 2px solid <?php echo esc_attr($border_color) ?>;
            }
            </style>
        <?php 
		}
    }
    new WPF_Product_Options_Frontend();
}